@@ -1,11 +1,14 @@
 """Server functions for loading translations
 """
+from __future__ import annotations
+
 import errno
 import json
 import re
 from collections import defaultdict
 from os.path import dirname
 from os.path import join as pjoin
+from typing import Any
 
 I18N_DIR = dirname(__file__)
 # Cache structure:
@@ -15,7 +18,7 @@ I18N_DIR = dirname(__file__)
 #     ...
 #   }
 # }}
-TRANSLATIONS_CACHE = {"nbjs": {}}
+TRANSLATIONS_CACHE: dict[str, Any] = {"nbjs": {}}
 
 
 _accept_lang_re = re.compile(
@@ -42,10 +45,7 @@ def parse_accept_lang_header(accept_lang):
         lang, qvalue = m.group("lang", "qvalue")
         # Browser header format is zh-CN, gettext uses zh_CN
         lang = lang.replace("-", "_")
-        if qvalue is None:
-            qvalue = 1.0
-        else:
-            qvalue = float(qvalue)
+        qvalue = 1.0 if qvalue is None else float(qvalue)
         if qvalue == 0:
             continue  # 0 means not accepted
         by_q[qvalue].append(lang)
@@ -59,7 +59,7 @@ def parse_accept_lang_header(accept_lang):
 def load(language, domain="nbjs"):
     """Load translations from an nbjs.json file"""
     try:
-        f = open(pjoin(I18N_DIR, language, "LC_MESSAGES", "nbjs.json"), encoding="utf-8")
+        f = open(pjoin(I18N_DIR, language, "LC_MESSAGES", "nbjs.json"), encoding="utf-8")  # noqa
     except OSError as e:
         if e.errno != errno.ENOENT:
             raise
@@ -87,7 +87,7 @@ def combine_translations(accept_language, domain="nbjs"):
     Returns data re-packaged in jed1.x format.
     """
     lang_codes = parse_accept_lang_header(accept_language)
-    combined = {}
+    combined: dict[str, Any] = {}
     for language in lang_codes:
         if language == "en":
             # en is default, all translations are in frontend.
