@@ -2,7 +2,7 @@
 """
 from tornado import ioloop, web
 
-from jupyter_server.auth import authorized
+from jupyter_server.auth.decorator import authorized
 from jupyter_server.base.handlers import JupyterHandler
 
 AUTH_RESOURCE = "server"
